@@ -2,10 +2,20 @@ package Alien::FFI;
 
 use strict;
 use warnings;
+use Config;
 use base qw( Alien::Base );
 
 # ABSTRACT: Build and make available libffi
-our $VERSION = '0.02'; # VERSION
+our $VERSION = '0.03'; # VERSION
+
+sub libs
+{
+  shift->SUPER::libs(@_) . (
+       $^O eq 'openbsd'
+    && !$Config{usethreads} 
+    && Alien::FFI->install_type eq 'share' 
+    ? ' /usr/lib/libpthread.a' : '');
+}
 
 
 1;
@@ -22,7 +32,7 @@ Alien::FFI - Build and make available libffi
 
 =head1 VERSION
 
-version 0.02
+version 0.03
 
 =head1 SYNOPSIS
 
